
# Type: gene regulatory relationship_subject




URI: [biolink:gene_regulatory_relationship_subject](https://w3id.org/biolink/vocab/gene_regulatory_relationship_subject)


## Domain and Range

[GeneRegulatoryRelationship](GeneRegulatoryRelationship.md) ->  <sub>REQ</sub> [GeneOrGeneProduct](GeneOrGeneProduct.md)

## Parents

 *  is_a: [subject](subject.md)

## Children


## Used by

 * [GeneRegulatoryRelationship](GeneRegulatoryRelationship.md)
